@@ -20,8 +20,6 @@
 
 #include "contextmenuextension.h"
 
-#include "qtcompat_p.h"
-
 #include <QMap>
 
 #include <QMenu>
@@ -54,7 +52,7 @@ public:
 };
 
 ContextMenuExtension::ContextMenuExtension()
-    : d(new ContextMenuExtensionPrivate)
+    : d_ptr(new ContextMenuExtensionPrivate)
 {
 }
 
@@ -62,33 +60,41 @@ ContextMenuExtension::~ContextMenuExtension() = default;
 
 
 ContextMenuExtension::ContextMenuExtension( const ContextMenuExtension& rhs )
-    : d( new ContextMenuExtensionPrivate )
+    : d_ptr(new ContextMenuExtensionPrivate)
 {
-    d->extensions = rhs.d->extensions;
+    Q_D(ContextMenuExtension);
+
+    d->extensions = rhs.d_func()->extensions;
 }
 
 ContextMenuExtension& ContextMenuExtension::operator=( const ContextMenuExtension& rhs )
 {
+    Q_D(ContextMenuExtension);
+
     if( this == &rhs )
         return *this;
 
-    d->extensions = rhs.d->extensions;
+    d->extensions = rhs.d_func()->extensions;
     return *this;
 }
 
 QList<QAction*> ContextMenuExtension::actions( const QString& group ) const
 {
+    Q_D(const ContextMenuExtension);
+
     return d->extensions.value( group, QList<QAction*>() );
 }
 
 void ContextMenuExtension::addAction( const QString& group, QAction* action )
 {
-    if( !d->extensions.contains( group ) )
-    {
+    Q_D(ContextMenuExtension);
+
+    auto actionGroupIt = d->extensions.find(group);
+    if (actionGroupIt == d->extensions.end()) {
         d->extensions.insert( group, QList<QAction*>() << action );
     } else
     {
-        d->extensions[group].append( action );
+        actionGroupIt->append(action);
     }
 }
 
@@ -137,11 +143,11 @@ void ContextMenuExtension::populateMenu(QMenu* menu, const QList<ContextMenuExte
     populateMenuWithGroup(menu, extensions, BuildGroup);
     populateMenuWithGroup(menu, extensions, FileGroup);
     populateMenuWithGroup(menu, extensions, EditGroup);
-    populateMenuWithGroup(menu, extensions, DebugGroup, i18n("Debug"));
-    populateMenuWithGroup(menu, extensions, RefactorGroup, i18n("Refactor"));
+    populateMenuWithGroup(menu, extensions, DebugGroup, i18nc("@title:menu", "Debug"));
+    populateMenuWithGroup(menu, extensions, RefactorGroup, i18nc("@title:menu", "Refactor"));
     populateMenuWithGroup(menu, extensions, NavigationGroup);
-    populateMenuWithGroup(menu, extensions, AnalyzeFileGroup, i18n("Analyze Current File With"), QStringLiteral("dialog-ok"), true, false);
-    populateMenuWithGroup(menu, extensions, AnalyzeProjectGroup, i18n("Analyze Current Project With"), QStringLiteral("dialog-ok"), true);
+    populateMenuWithGroup(menu, extensions, AnalyzeFileGroup, i18nc("@title:menu", "Analyze Current File With"), QStringLiteral("dialog-ok"), true, false);
+    populateMenuWithGroup(menu, extensions, AnalyzeProjectGroup, i18nc("@title:menu", "Analyze Current Project With"), QStringLiteral("dialog-ok"), true);
     populateMenuWithGroup(menu, extensions, VcsGroup);
     populateMenuWithGroup(menu, extensions, ExtensionGroup);
 }
