@@ -33,13 +33,6 @@ namespace Sublime {
 class MainWindow;
 }
 
-/**
- * This macro adds an extension interface to register with the extension manager
- * Call this macro for all interfaces your plugin implements in its constructor
- */
-#define KDEV_USE_EXTENSION_INTERFACE(Extension) \
-    _Pragma("message(\"Using deprecated function: KDEV_USE_EXTENSION_INTERFACE. Just remove the use of it.\")")
-
 namespace KDevelop
 {
 
@@ -48,6 +41,7 @@ class ConfigPage;
 class Context;
 class ContextMenuExtension;
 struct ProjectConfigOptions;
+class IPluginPrivate;
 
 /**
  * The base class for all KDevelop plugins.
@@ -269,7 +263,8 @@ protected:
     virtual void initializeGuiState();
 
 private:
-    const QScopedPointer<class IPluginPrivate> d;
+    const QScopedPointer<class IPluginPrivate> d_ptr;
+    Q_DECLARE_PRIVATE(IPlugin)
     friend class IPluginPrivate;
 };
 
