@@ -33,6 +33,13 @@
 
 namespace KDevelop {
 
+using TextStreamFunction = QTextStream& (*)(QTextStream&);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+constexpr TextStreamFunction endl = Qt::endl;
+#else
+constexpr TextStreamFunction endl = ::endl;
+#endif
+
 QString lockFileForSession( const QString& id )
 {
     return SessionController::sessionDirectory( id ) + QLatin1String("/lock");
@@ -193,10 +200,10 @@ QString SessionLock::handleLockedSession(const QString& sessionName, const QStri
     QString errmsg = QLatin1String("<p>") + problemHeader + QLatin1String("<br>") + problemDescription + QLatin1String("</p>") + problemResolution;
 
     KGuiItem retry = KStandardGuiItem::cont();
-    retry.setText(i18nc("@action:button", "Retry startup"));
+    retry.setText(i18nc("@action:button", "Retry Startup"));
 
     KGuiItem choose = KStandardGuiItem::configure();
-    choose.setText(i18nc("@action:button", "Choose another session"));
+    choose.setText(i18nc("@action:button", "Choose Another Session"));
 
     KGuiItem cancel = KStandardGuiItem::quit();
     int ret = KMessageBox::warningYesNoCancel(nullptr, errmsg, i18nc("@title:window", "Failed to Lock Session %1", sessionName),
