@@ -71,6 +71,16 @@ public:
     using Ptr = QExplicitlySharedDataPointer<ClangProblem>;
     using ConstPtr = QExplicitlySharedDataPointer<const ClangProblem>;
 
+    /**
+     * Creates an empty ClangProblem.
+     */
+    ClangProblem();
+
+    /**
+     * Creates a deep copy of a ClangProblem.
+     */
+    ClangProblem(const ClangProblem& other);
+
     /**
      * Import @p diagnostic into a ClangProblem object
      *
